@@ -2,10 +2,12 @@
 Compliance Checker suite runner
 """
 from __future__ import print_function
+from __future__ import unicode_literals
 
 import sys
 import inspect
 import itertools
+from operator import itemgetter
 import json
 from netCDF4 import Dataset
 from lxml import etree as ET
@@ -35,10 +37,28 @@ class CheckSuite(object):
         for x in working_set.iter_entry_points('compliance_checker.suites'):
             try:
                 xl = x.load()
+                cls.checkers[':'.join((xl._cc_spec, xl._cc_spec_version))] = xl
+            # TODO: remove this once all checkers move over to the new
+            #       _cc_spec, _cc_spec_version
+            except AttributeError:
+                # if there are versioned classes, it will get overwritten by the
+                # latest version later.  If there are not, it will be assigned
+                # the checker as the main class
+                # TODO: nix name attribute in plugins.  Keeping in for now
+                #       to provide backwards compatibility
+                cls.checkers[getattr(xl, 'name', None) or xl._cc_spec] = xl
 
-                cls.checkers[xl.name] = xl
             except Exception as e:
                 print("Could not load", x, ":", e, file=sys.stderr)
+        # find the latest version of versioned checkers and set that as the
+        # default checker for compliance checker if no version is specified
+        ver_checkers = [c.split(':', 1) for c in cls.checkers if ':' in c]
+        for spec, versions in itertools.groupby(ver_checkers, itemgetter(0)):
+            # right now this looks for character order. May break if
+            # version specifications become more complicated
+            latest_version = max(v[-1] for v in versions)
+            cls.checkers[spec] = cls.checkers[spec + ':latest'] = \
+                cls.checkers[':'.join((spec, latest_version))]
 
     def _get_checks(self, checkclass):
         """
@@ -74,10 +94,12 @@ class CheckSuite(object):
 
         while len(checker_queue):
             name, a = checker_queue.pop()
+            # is the current dataset type in the supported filetypes
+            # for the checker class?
             if type(ds) in a().supported_ds:
                 valid.append((name, a))
 
-            # add all to queue
+            # add any subclasses of the checker class
             for subc in a.__subclasses__():
                 if subc not in all_checked:
                     all_checked.add(subc)
@@ -224,7 +246,7 @@ class CheckSuite(object):
         aggregates = self.build_structure(check_name, groups, source_name, limit)
         aggregates = self.serialize(aggregates)
         json_string = json.dumps(aggregates, ensure_ascii=False)
-        file_object.write(str(json_string))
+        file_object.write(json_string)
         return
 
     def serialize(self, o):
@@ -261,22 +283,25 @@ class CheckSuite(object):
         template_vars = self.build_structure(check_name, groups, source_name, limit)
 
         buf = template.render(**template_vars)
-        file_object.write(str(buf))
+
+        file_object.write(buf)
 
     def get_points(self, groups, limit):
         score_list = []
         score_only_list = []
 
-        for v in range(len(groups)):
-            score_list.append([groups[v].name, groups[v].weight, groups[v].value, groups[v].children])
-            if groups[v].weight >= limit:
-                score_only_list.append(groups[v].value)
+        for g in groups:
+            score_list.append([g.name, g.weight, g.value, g.children])
+            if g.weight >= limit:
+                score_only_list.append(g.value)
 
         points = [x[0] for x in score_only_list]
         out_of = [x[1] for x in score_only_list]
 
         points = sum(points)
         out_of = sum(out_of)
+        # sorts lists into high/medium/low order
+        score_list.sort(key=lambda x: x[1], reverse=True)
 
         return score_list, points, out_of
 
@@ -434,14 +459,29 @@ class CheckSuite(object):
         wrapper = textwrap.TextWrapper(initial_indent = '', width = 80, subsequent_indent = ' ' * 54)
         for res in grouped_sorted:
             if (res.value[0] != res.value[1]) and not res.msgs:
-                print('%-39s:%1s:%6s/%2s : %s' % (str(indent * '    ' + res.name)[0:39], res.weight, str(res.value[0]), str(res.value[1]), ' '))
+                print('%-39s:%1s:%6s/%2s : %s' % ((indent * '    ' + res.name)[0:39], res.weight, res.value[0], res.value[1], ' '))
 
             if (res.value[0] != res.value[1]) and res.msgs:
-                print(wrapper.fill('%-39s:%1s:%6s/%2s : %s' % (str(indent * '    ' + res.name)[0:39], res.weight, str(res.value[0]), str(res.value[1]), str(", ".join(res.msgs)))))
+                print(wrapper.fill('%-39s:%1s:%6s/%2s : %s' % ((indent * '    ' + res.name)[0:39], res.weight, res.value[0], res.value[1], ", ".join(res.msgs))))
 
             if res.children:
                 self.reasoning_routine(res.children, indent + 1, False)
 
+    def process_doc(doc):
+        """
+        Attempt to parse an xml string conforming to either an SOS or SensorML
+        dataset and return the results
+        """
+        xml_doc = ET.fromstring(str(doc))
+        if xml_doc.tag == "{http://www.opengis.net/sos/1.0}Capabilities":
+            ds = SensorObservationService(ds_str, xml=str(doc))
+
+        elif xml_doc.tag == "{http://www.opengis.net/sensorML/1.0.1}SensorML":
+            ds = SensorML(xml_doc)
+        else:
+            raise ValueError("Unrecognized XML root element: %s" % xml_doc.tag)
+        return ds
+
     def load_dataset(self, ds_str):
         """
         Helper method to load a dataset or SOS GC/DS url.
@@ -452,7 +492,7 @@ class CheckSuite(object):
         doc = None
         pr = urlparse(ds_str)
         if pr.netloc:       # looks like a remote url
-            rhead = requests.head(ds_str)
+            rhead = requests.head(ds_str, allow_redirects=True)
 
             # if we get a 400 here, it's likely a Dataset openable OpenDAP url
             if rhead.status_code == 400:
@@ -469,9 +509,16 @@ class CheckSuite(object):
             def is_binary_string(bts):
                 # do a cheap imitation of libmagic
                 # http://stackoverflow.com/a/7392391/84732
-                textchars = ''.join(map(chr, [7, 8, 9, 10, 12, 13, 27] + list(range(0x20, 0x100))))
                 if sys.version_info >= (3, ):
-                    textchars = textchars.encode()
+                    join_str = ''
+                    textchars = join_str.join(map(chr, [7, 8, 9, 10, 12, 13, 27]
+                                                  + list(range(0x20, 0x100)))).encode()
+                else:
+                    # because of `unicode_literals` import, we need to convert
+                    # to a Py2 string/bytes
+                    join_str = str('')
+                    textchars = join_str.join(map(chr, [7, 8, 9, 10, 12, 13, 27]
+                                                  + list(range(0x20, 0x100))))
                 return bool(bts.translate(None, textchars))
 
             with open(ds_str, 'rb') as f:
@@ -484,14 +531,7 @@ class CheckSuite(object):
                     doc = "".join(f.readlines())
 
         if doc is not None:
-            xml_doc = ET.fromstring(str(doc))
-            if xml_doc.tag == "{http://www.opengis.net/sos/1.0}Capabilities":
-                ds = SensorObservationService(ds_str, xml=str(doc))
-
-            elif xml_doc.tag == "{http://www.opengis.net/sensorML/1.0.1}SensorML":
-                ds = SensorML(xml_doc)
-            else:
-                raise Exception("Unrecognized XML root element: %s" % xml_doc.tag)
+            ds = process_doc(doc)
         else:
             # no doc? try the dataset constructor
             ds = Dataset(ds_str)
@@ -551,7 +591,8 @@ class CheckSuite(object):
                 retval = r.name
             return retval
 
-        grouped = itertools.groupby(sorted(raw_scores, key=group_func), key=group_func)
+        grouped = itertools.groupby(sorted(raw_scores, key=group_func),
+                                    key=group_func)
 
         ret_val = []
 
